@@ -254,18 +254,20 @@ def parse_eff(eff, pos, pad):
         codon_ref = eff.transcript.coding_sequence[
             codon_start : codon_start + 3
         ]
-        if mut_type == "Silent":
-            aa_pos = eff.aa_pos
-            aa_ref = eff.aa_ref if coding_pos else None
-        elif mut_type in ["IntronicSpliceSite", "ExonicSpliceSite"]:
-            aa_pos = eff.alternate_effect.aa_pos
-            aa_ref = eff.alternate_effect.aa_ref if coding_pos else None
-        elif mut_type == "StopLoss":
-            aa_pos = eff.aa_mutation_start_offset + 1
-            aa_ref = "*"
+        if coding_pos == None:
+            aa_pos = None
+            aa_ref = None
         else:
-            aa_pos = eff.aa_mutation_start_offset + 1
-            aa_ref = eff.aa_ref if coding_pos else None
+            if mut_type == "Silent":
+                aa_pos = eff.aa_pos
+            elif mut_type in ["IntronicSpliceSite", "ExonicSpliceSite"]:
+                aa_pos = eff.alternate_effect.aa_pos
+            else:
+                aa_pos = eff.aa_mutation_start_offset + 1
+            aa_ref = eff.original_protein_sequence[(coding_pos - 1) // 3]
+
+        if mut_type == "StopLoss":
+            aa_ref = "*"
         if aa_ref == "":
             aa_pos = None
             aa_ref = None
@@ -319,7 +321,12 @@ def site2mut(
     context_settings=dict(help_option_names=["-h", "--help"]),
 )
 @click.option(
-    "--input", "-i", "input", help="Input position file.", required=True
+    "--input",
+    "-i",
+    "input",
+    default="-",
+    help="Input position file.",
+    required=False,
 )
 @click.option(
     "--output",
@@ -412,25 +419,23 @@ def run(
         ensembl_genome.download()
         ensembl_genome.index()
 
-    with open(input, "r") as f:
+    with click.open_file(input, "r") as input_file, click.open_file(
+        output, "w"
+    ) as output_file:
         annot_header = REPORT_FEATURES
         if with_header:
-            input_header = f.readline().strip().split()
+            input_header = input_file.readline().strip().split()
         else:
             input_header = ["chrom", "pos", "strand", "ref", "alt"]
 
-        if output == "-":
-            output_file = sys.stdout
-        else:
-            output_file = open(output, "w")
         print("#" + "\t".join(input_header + annot_header), file=output_file)
-        for l in f:
+        for l in input_file:
             input_cols = l.strip("\n").split("\t")
             if len(input_cols) >= 5:
                 c, p, s, ref, alt = [input_cols[i] for i in columns_index]
             else:
                 c, p, s = [input_cols[i] for i in columns_index[:3]]
-                ref, alt = "-", "-"
+                ref, alt = "-", "N"
             if strandness:
                 if s == "-":
                     ref = reverse_base(ref.upper())
